@@ -39,6 +39,7 @@ import (
 	knativeclient "knative.dev/networking/pkg/client/injection/client"
 	ingressinformer "knative.dev/networking/pkg/client/injection/informers/networking/v1alpha1/ingress"
 	v1alpha1ingress "knative.dev/networking/pkg/client/injection/reconciler/networking/v1alpha1/ingress"
+	"knative.dev/networking/pkg/status"
 	kubeclient "knative.dev/pkg/client/injection/kube/client"
 	endpointsinformer "knative.dev/pkg/client/injection/kube/informers/core/v1/endpoints"
 	podinformer "knative.dev/pkg/client/injection/kube/informers/core/v1/pod"
@@ -48,7 +49,6 @@ import (
 	"knative.dev/pkg/network"
 	knativeReconciler "knative.dev/pkg/reconciler"
 	"knative.dev/pkg/tracker"
-	"knative.dev/serving/pkg/network/status"
 )
 
 const (
@@ -84,13 +84,12 @@ func NewController(ctx context.Context, cmw configmap.Watcher) *controller.Impl
 	}
 
 	r := &Reconciler{
-		kubeClient:    kubernetesClient,
-		knativeClient: knativeClient,
-		caches:        caches,
-		extAuthz:      extAuthZConfig.Enabled,
+		kubeClient: kubernetesClient,
+		caches:     caches,
+		extAuthz:   extAuthZConfig.Enabled,
 	}
 
-	impl := v1alpha1ingress.NewImpl(ctx, r)
+	impl := v1alpha1ingress.NewImpl(ctx, r, config.KourierIngressClassName)
 
 	classFilter := knativeReconciler.AnnotationFilterFunc(
 		networking.IngressClassAnnotationKey, config.KourierIngressClassName, false,
@@ -142,22 +141,22 @@ func NewController(ctx context.Context, cmw configmap.Watcher) *controller.Impl
 		r.kubeClient, endpointsInformer.Lister(), network.GetClusterDomainName(), endpointsTracker, logger)
 	r.ingressTranslator = &ingressTranslator
 
+	// Initialize the Envoy snapshot.
+	snapshot, err := r.caches.ToEnvoySnapshot()
+	if err != nil {
+		logger.Fatalw("Failed to create snapshot", zap.Error(err))
+	}
+	err = r.xdsServer.SetSnapshot(&snapshot, nodeID)
+	if err != nil {
+		logger.Fatalw("Failed to set snapshot", zap.Error(err))
+	}
+
 	// Let's start the management server when our cache is in sync, to avoid sending an incomplete configuration
 	// to an already running gateway container. If the cache is not warmed up after "cacheWarmUPTimeout" we just
 	// start the server as somehow we couldn't sync.
 	go func() {
 		waitForCache(logger, caches)
-
-		snapshot, err := r.caches.ToEnvoySnapshot()
-		if err != nil {
-			logger.Fatalw("Failed to create snapshot", zap.Error(err))
-		}
-		err = r.xdsServer.SetSnapshot(&snapshot, nodeID)
-		if err != nil {
-			logger.Fatalw("Failed to set snapshot", zap.Error(err))
-		}
 		go envoyXdsServer.RunManagementServer()
-
 		<-ctx.Done()
 	}()
 
