@@ -29,9 +29,8 @@ import (
 	"knative.dev/net-kourier/pkg/config"
 	"knative.dev/net-kourier/pkg/knative"
 	"knative.dev/networking/pkg/apis/networking/v1alpha1"
+	"knative.dev/networking/pkg/status"
 	"knative.dev/pkg/network"
-	"knative.dev/pkg/system"
-	"knative.dev/serving/pkg/network/status"
 )
 
 func NewProbeTargetLister(logger *zap.SugaredLogger, endpointsLister corev1listers.EndpointsLister) status.ProbeTargetLister {
@@ -48,7 +47,7 @@ type gatewayPodTargetLister struct {
 
 func (l *gatewayPodTargetLister) ListProbeTargets(ctx context.Context, ing *v1alpha1.Ingress) ([]status.ProbeTarget, error) {
 
-	eps, err := l.endpointsLister.Endpoints(system.Namespace()).Get(config.InternalServiceName)
+	eps, err := l.endpointsLister.Endpoints(knative.GetGatewayNamespace()).Get(config.InternalServiceName)
 	if err != nil {
 		return nil, fmt.Errorf("failed to get internal service: %w", err)
 	}
@@ -124,7 +123,7 @@ func getInternalDomains(rule v1alpha1.IngressRule, localDomainName string) []str
 	var res []string
 
 	for _, host := range rule.Hosts {
-		if strings.Contains(host, localDomainName) {
+		if strings.HasSuffix(host, localDomainName) {
 			res = append(res, host)
 		}
 	}
@@ -135,7 +134,7 @@ func getInternalDomains(rule v1alpha1.IngressRule, localDomainName string) []str
 func getExternalDomains(rule v1alpha1.IngressRule, localDomainName string) []string {
 	var res []string
 	for _, host := range rule.Hosts {
-		if !strings.Contains(host, localDomainName) {
+		if !strings.HasSuffix(host, localDomainName) {
 			res = append(res, host)
 		}
 	}
