@@ -23,8 +23,8 @@ import (
 
 	"k8s.io/apimachinery/pkg/util/intstr"
 	"knative.dev/networking/pkg/apis/networking/v1alpha1"
+	"knative.dev/networking/test"
 	pkgTest "knative.dev/pkg/test"
-	"knative.dev/serving/test"
 )
 
 const (
